@@ -37,6 +37,18 @@ class ContainerStatusField(fields.BaseEnumField):
     AUTO_TYPE = ContainerStatus()
 
 
+class CapsuleStatus(fields.Enum):
+    ALL = consts.CAPSULE_STATUSES
+
+    def __init__(self):
+        super(CapsuleStatus, self).__init__(
+            valid_values=CapsuleStatus.ALL)
+
+
+class CapsuleStatusField(fields.BaseEnumField):
+    AUTO_TYPE = CapsuleStatus()
+
+
 class TaskState(fields.Enum):
     ALL = consts.TASK_STATES
 
@@ -71,6 +83,14 @@ class JsonField(fields.AutoTypedField):
     AUTO_TYPE = Json()
 
 
+class SetOfStringsField(fields.AutoTypedField):
+    AUTO_TYPE = fields.Set(fields.String())
+
+
+class ListOfListsOfStringsField(fields.AutoTypedField):
+    AUTO_TYPE = fields.List(fields.List(fields.String()))
+
+
 class ResourceClass(fields.Enum):
     ALL = consts.RESOURCE_CLASSES
 
@@ -107,8 +127,8 @@ class PciDeviceType(BaseZunEnum):
 
 
 class PciDeviceTypeField(fields.BaseEnumField):
-        AUTO_TYPE = PciDeviceType()
+    AUTO_TYPE = PciDeviceType()
 
 
 class PciDeviceStatusField(fields.BaseEnumField):
-        AUTO_TYPE = PciDeviceStatus()
+    AUTO_TYPE = PciDeviceStatus()
