@@ -24,6 +24,7 @@ from zun.compute import manager
 import zun.conf
 from zun import objects
 from zun.objects.container import Container
+from zun.objects.container_action import ContainerAction
 from zun.objects.container_action import ContainerActionEvent
 from zun.objects.exec_instance import ExecInstance
 from zun.objects.image import Image
@@ -94,6 +95,10 @@ class TestManager(base.TestCase):
 
     def setUp(self):
         super(TestManager, self).setUp()
+        p = mock.patch('zun.scheduler.client.report.SchedulerReportClient')
+        p.start()
+        self.addCleanup(p.stop)
+
         zun.conf.CONF.set_override(
             'container_driver',
             'zun.tests.unit.container.fake_driver.FakeDriver')
@@ -330,6 +335,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
     @mock.patch.object(VolumeMapping, 'count',
@@ -346,7 +352,8 @@ class TestManager(base.TestCase):
             self, mock_start, mock_create,
             mock_is_volume_available, mock_attach_volume,
             mock_detach_volume, mock_pull, mock_list_by_container, mock_count,
-            mock_save, mock_spawn_n, mock_event_finish, mock_event_start):
+            mock_save, mock_spawn_n, mock_action_finish, mock_event_finish,
+            mock_event_start):
         container = Container(self.context, **utils.get_test_container())
         image = {'image': 'repo', 'path': 'out_path', 'driver': 'glance'}
         mock_create.return_value = container
@@ -377,6 +384,7 @@ class TestManager(base.TestCase):
     @mock.patch.object(fake_driver, 'delete_volume')
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
     @mock.patch.object(VolumeMapping, 'count',
@@ -396,8 +404,8 @@ class TestManager(base.TestCase):
             mock_is_volume_available, mock_attach_volume,
             mock_detach_volume, mock_pull, mock_list_by_container,
             mock_list_by_volume, mock_count, mock_save,
-            mock_spawn_n, mock_event_finish, mock_event_start,
-            mock_delete_volume):
+            mock_spawn_n, mock_action_finish, mock_event_finish,
+            mock_event_start, mock_delete_volume):
         mock_is_volume_available.return_value = True, False
         mock_attach_volume.side_effect = [None, base.TestingException("fake")]
         container = Container(self.context, **utils.get_test_container())
@@ -433,6 +441,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
     @mock.patch.object(VolumeMapping, 'count',
@@ -449,7 +458,7 @@ class TestManager(base.TestCase):
             self, mock_pull, mock_is_volume_available,
             mock_attach_volume, mock_detach_volume,
             mock_list_by_container, mock_list_by_volume, mock_count,
-            mock_save, mock_spawn_n, mock_event_finish,
+            mock_save, mock_spawn_n, mock_action_finish, mock_event_finish,
             mock_event_start):
         container_dict = utils.get_test_container(
             image='test:latest', image_driver='docker',
@@ -482,6 +491,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
     @mock.patch.object(VolumeMapping, 'count',
@@ -498,7 +508,7 @@ class TestManager(base.TestCase):
             self, mock_pull, mock_is_volume_available,
             mock_attach_volume, mock_detach_volume,
             mock_list_by_container, mock_list_by_volume, mock_count,
-            mock_save, mock_spawn_n, mock_event_finish,
+            mock_save, mock_spawn_n, mock_action_finish, mock_event_finish,
             mock_event_start):
         container_dict = utils.get_test_container(
             image='test:latest', image_driver='docker',
@@ -531,6 +541,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
     @mock.patch.object(VolumeMapping, 'count',
@@ -547,7 +558,7 @@ class TestManager(base.TestCase):
             self, mock_pull, mock_is_volume_available,
             mock_attach_volume, mock_detach_volume,
             mock_list_by_container, mock_list_by_volume, mock_count,
-            mock_save, mock_spawn_n, mock_event_finish,
+            mock_save, mock_spawn_n, mock_action_finish, mock_event_finish,
             mock_event_start):
         container_dict = utils.get_test_container(
             image='test:latest', image_driver='docker',
@@ -580,6 +591,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(Container, 'save')
     @mock.patch.object(VolumeMapping, 'count',
@@ -597,7 +609,7 @@ class TestManager(base.TestCase):
             self, mock_create, mock_pull, mock_is_volume_available,
             mock_attach_volume, mock_detach_volume,
             mock_list_by_container, mock_list_by_volume, mock_count,
-            mock_save, mock_spawn_n,
+            mock_save, mock_spawn_n, mock_action_finish,
             mock_event_finish, mock_event_start):
         container = Container(self.context, **utils.get_test_container())
         image = {'image': 'repo', 'path': 'out_path', 'driver': 'glance',
@@ -632,6 +644,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch('zun.common.utils.spawn_n')
     @mock.patch.object(objects.Capsule, 'save')
     @mock.patch.object(objects.CapsuleContainer, 'list_by_capsule_id')
@@ -651,7 +664,8 @@ class TestManager(base.TestCase):
             mock_is_volume_available, mock_attach_volume,
             mock_detach_volume, mock_pull, mock_list_by_container, mock_count,
             mock_init_container_list, mock_capsule_container_list,
-            mock_save, mock_spawn_n, mock_event_finish, mock_event_start):
+            mock_save, mock_spawn_n, mock_action_finish, mock_event_finish,
+            mock_event_start):
         capsule = objects.Capsule(self.context, **utils.get_test_container())
         image = {'image': 'repo', 'path': 'out_path', 'driver': 'glance'}
         mock_create.return_value = capsule
@@ -778,6 +792,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch('zun.compute.manager.Manager._get_vol_info')
     @mock.patch('zun.compute.manager.Manager._get_network_info')
     @mock.patch.object(fake_driver, 'pull_image')
@@ -788,6 +803,7 @@ class TestManager(base.TestCase):
     def test_container_rebuild(self, mock_delete, mock_create,
                                mock_save, mock_check, mock_pull,
                                mock_get_network_info, mock_get_vol_info,
+                               mock_action_finish,
                                mock_event_finish, mock_event_start):
         container = Container(self.context, **utils.get_test_container())
         image = {'image': 'repo', 'path': 'out_path', 'driver': 'glance'}
@@ -803,6 +819,7 @@ class TestManager(base.TestCase):
         mock_delete.assert_called_once_with(self.context, container, True)
         mock_event_start.assert_called_once()
         mock_event_finish.assert_called_once()
+        mock_action_finish.assert_called_once()
         self.assertEqual(
             (self.context, container.uuid, 'compute__do_container_rebuild'),
             mock_event_finish.call_args[0])
@@ -811,12 +828,15 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
+    @mock.patch.object(Container, 'save')
     @mock.patch('zun.compute.manager.Manager._get_vol_info')
     @mock.patch('zun.compute.manager.Manager._get_network_info')
     @mock.patch.object(manager.Manager, '_fail_container')
     def test_container_rebuild_failed(
             self, mock_fail, mock_get_network_info, mock_get_vol_info,
-            mock_event_finish, mock_event_start):
+            mock_save, mock_action_finish, mock_event_finish,
+            mock_event_start):
         mock_get_vol_info.return_value = []
         fake_exc = exception.PortNotFound(port='fake-port')
         mock_get_network_info.side_effect = fake_exc
@@ -828,6 +848,7 @@ class TestManager(base.TestCase):
                                      container, str(fake_exc))
         mock_event_start.assert_called_once()
         mock_event_finish.assert_called_once()
+        mock_action_finish.assert_called_once()
         self.assertEqual(
             (self.context, container.uuid, 'compute__do_container_rebuild'),
             mock_event_finish.call_args[0])
@@ -1249,6 +1270,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch.object(fake_driver, 'upload_image_data')
     @mock.patch.object(fake_driver, 'get_image')
     @mock.patch.object(fake_driver, 'commit')
@@ -1257,8 +1279,8 @@ class TestManager(base.TestCase):
     @mock.patch.object(Container, 'save')
     def test_container_commit(
             self, mock_save, mock_unpause, mock_pause, mock_commit,
-            mock_get_image, mock_upload_image_data, mock_event_finish,
-            mock_event_start):
+            mock_get_image, mock_upload_image_data, mock_action_finish,
+            mock_event_finish, mock_event_start):
         container = Container(self.context, **utils.get_test_container(
             status=consts.PAUSED))
         mock_get_image_response = mock.MagicMock()
@@ -1281,6 +1303,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch.object(fake_driver, 'upload_image_data')
     @mock.patch.object(fake_driver, 'get_image')
     @mock.patch.object(fake_driver, 'commit')
@@ -1289,8 +1312,8 @@ class TestManager(base.TestCase):
     @mock.patch.object(Container, 'save')
     def test_container_commit_with_pause(
             self, mock_save, mock_unpause, mock_pause, mock_commit,
-            mock_get_image, mock_upload_image_data, mock_event_finish,
-            mock_event_start):
+            mock_get_image, mock_upload_image_data, mock_action_finish,
+            mock_event_finish, mock_event_start):
         container = Container(self.context, **utils.get_test_container())
         mock_get_image_response = mock.MagicMock()
         mock_get_image_response.data = StringIO().read()
@@ -1314,6 +1337,7 @@ class TestManager(base.TestCase):
 
     @mock.patch.object(ContainerActionEvent, 'event_start')
     @mock.patch.object(ContainerActionEvent, 'event_finish')
+    @mock.patch.object(ContainerAction, 'action_finish')
     @mock.patch.object(fake_driver, 'delete_committed_image')
     @mock.patch.object(fake_driver, 'commit')
     @mock.patch.object(fake_driver, 'pause')
@@ -1321,6 +1345,7 @@ class TestManager(base.TestCase):
     @mock.patch.object(Container, 'save')
     def test_container_commit_failed(self, mock_save, mock_unpause, mock_pause,
                                      mock_commit, mock_delete,
+                                     mock_action_finish,
                                      mock_event_finish, mock_event_start):
         container = Container(self.context, **utils.get_test_container())
         mock_get_image_response = mock.MagicMock()
