@@ -16,7 +16,6 @@ from oslo_config import cfg
 from zun.common import consts
 from zun.common import name_generator
 from zun.db import api as db_api
-from zun.db.etcd import api as etcd_api
 from zun.objects.container import Cpuset
 
 CONF = cfg.CONF
@@ -81,6 +80,7 @@ def get_test_container(**kwargs):
                                      {'Name': 'no', 'MaximumRetryCount': '0'}),
         'status_detail': kwargs.get('status_detail', 'up from 5 hours'),
         'interactive': kwargs.get('interactive', True),
+        'tty': kwargs.get('tty', True),
         'image_driver': kwargs.get('image_driver', 'glance'),
         'websocket_url': 'ws://127.0.0.1:6784/4c03164962fa/attach/'
                          'ws?logs=0&stream=1&stdin=1&stdout=1&stderr=1',
@@ -106,10 +106,7 @@ def get_test_container(**kwargs):
 
 
 def _get_dbapi():
-    if CONF.database.backend == 'sqlalchemy':
-        dbapi = db_api._get_dbdriver_instance()
-    else:
-        dbapi = etcd_api.get_backend()
+    dbapi = db_api._get_dbdriver_instance()
     return dbapi
 
 
@@ -364,6 +361,8 @@ def get_test_numa_topology(**kwargs):
 def get_test_compute_node(**kwargs):
     return {
         'uuid': kwargs.get('uuid', '24a5b17a-f2eb-4556-89db-5f4169d13982'),
+        'rp_uuid': kwargs.get('rp_uuid',
+                              '24a5b17a-f2eb-4556-89db-5f4169d13982'),
         'hostname': kwargs.get('hostname', 'localhost'),
         'numa_topology': kwargs.get('numa_topology', get_test_numa_topology()),
         'mem_total': kwargs.get('mem_total', 1024),
